#
# spec file for package ghc-doclayout
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name doclayout
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.5
Release:        1.1
Summary:        A prettyprinting library for laying out text documents
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-emojis-devel
BuildRequires:  ghc-emojis-prof
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-mtl-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-safe-devel
BuildRequires:  ghc-safe-prof
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-text-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-golden-devel
BuildRequires:  ghc-tasty-golden-prof
BuildRequires:  ghc-tasty-hunit-devel
BuildRequires:  ghc-tasty-hunit-prof
BuildRequires:  ghc-tasty-prof
BuildRequires:  ghc-tasty-quickcheck-devel
BuildRequires:  ghc-tasty-quickcheck-prof
%endif

%description
Doclayout is a prettyprinting library for laying out text documents, with
several features not present in prettyprinting libraries designed for code.
It was designed for use in pandoc.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE
%dir %{_datadir}/%{pkg_name}-%{version}
%{_datadir}/%{pkg_name}-%{version}/README.md

%files devel -f %{name}-devel.files
%doc changelog.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Mon Sep  9 2024 Peter Simons <psimons@suse.com>
- Update doclayout to version 0.5.
  [#]# 0.5
  * Extract existing HasChars definition into a module
    Text.DocLayout.HasChars (Evan Silberman).
  * Add a `build` method to the signature of HasChars [API change]
    (Evan Silberman). This has a default definition, and is only needed with
    the ANSI renderer, so existing users should not need to add anything to
    their HasChars instances.
  * Introduce support for ANSI-styled output (Evan Silberman) [API change].
    `renderPlain` and `renderANSI` are now exported; the old `render`
    is a synonym of `renderPlain`.  In addition, various functions are
    exported to add ANSI formatting (including bold, italics,
    underline, strikeout, links, and colors) to a Doc. The Attributed
    type is also now exported.
  * Change type of Block constructor, replacing `[a]` with `[Attributed a]`,
    which carries a Font along with an inner string type [API change]
    (Evan Silberman).
  * Introduce FlatDocs and use them for rendering (Evan Silberman).
    This is an internal concept, not part of the public API.
    FlatDoc is an "intermediate representation" for the Doc "interpreter".
    The general design is that any Doc can be turned into a list of FlatDocs
    that carry equivalent information. The main point of doing this
    is to replace the nested Styled and Linked Docs, which form a more
    complicated tree structure than previously existed in DocLayout.
  * Deprecate `unfoldD`.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Sun Mar 26 2023 Peter Simons <psimons@suse.com>
- Update doclayout to version 0.4.0.1.
  [#]# 0.4.0.1
  * Add clause for Empty to renderList (#22).
  * Remove upper bound for criterion
* Sat Aug 13 2022 Peter Simons <psimons@suse.com>
- Update doclayout to version 0.4 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Sat Apr  2 2022 Peter Simons <psimons@suse.com>
- Update doclayout to version 0.4.
  [#]# 0.4
  * Expose `unfoldD` [API change].
  * Remove `realLengthNoShortcut`, `isEmojiModifier`, and
    `isEmojiJoiner` [API change] (Stephen Morgan).
  * Add new exported functions `realLengthNarrowContext`,
    `realLengthWideContext`, `realLengthNarrowContextNoShortcut`,
    `realLengthWideContextNoShortcut`, `isSkinToneModifier`, `isZWJ`
    [API change] (Stephen Morgan).
  * Compute `realLength` strictly.
  * Make `getOffset` stricter.
  * Drop support for ghc <= 8.4, add test for ghc 9.2.
  * Don't collapse the CarriageReturn + Newline combination (#20).
    We want to ensure that a literal starting with a Newline
    doesn't lose the newline if it occurs after a CarriageReturn.
    This affects code blocks in pandoc that begin with newlines.
  * Improve performance of NoShortcut code (Stephen Morgan).
  * Simplify emoji processing (Stephen Morgan).
  * Add benchmarking for code with no shortcuts (Stephen Morgan).
  * Add unicodeWidth.inc to cabal file.
  * Fix `offset`, `minOffset`, `updateColumn` so they don't re-render.
  * Get unicode block widths directly from the Unicode specification, rather
    than writing it out ourselves (Stephen Morgan).
  * Resolve the width of ambiguous characters based on their context
    (Stephen Morgan).
  * Spacing marks should have nonzero width, even though they are combining
    characters (Stephen Morgan).
  * Add shortcuts for extended Latin, Arabic, Cyrillic, Greek,
    Devangari, Bengali, Korean, Telugu, and Tamil (Stephen Morgan).
  * Fix location of extra-source-files in cabal.
  * update.hs: require text package
  * Handle emoji variation modifiers specially, so the keypad emoji can be
    ignored (Stephen Morgan).  This results in a 16%% speedup of realLength
    on ascii text.
  * Add benchmarks for all scripts used by more than 50 million people, plus
    a couple more. (#9, Stephen Morgan).
* Tue Oct 12 2021 psimons@suse.com
- Update doclayout to version 0.3.1.1.
  [#]# 0.3.1.1
  * Fix the end of the block of zero width characters which contains
    the zero-width joiners and directional markings (Stephen Morgan, #5).
    This fixes a regression introduced in 0.3.1, affecting code
    points 0x2010 to 0x2030.
  [#]# 0.3.1
  * Improved handling of emojis.  Emojis are double-wide, but
    previously this library did not treat them as such.  We now
    have comprehensive support of emojis, including variation
    modifiers and zero-width joiners, verified by a test suite.
    Performance has been confirmed to be no worse for text without emojis.
    (Stephen Morgan, #1).  API changes: export `realLengthNoShortcut`,
    `isEmojiModifier`, `isEmojiVariation`, `isEmojiJoiner`.
* Tue Mar 16 2021 psimons@suse.com
- Update doclayout to version 0.3.0.2.
  [#]# 0.3.0.2
  * NOINLINE `literal` instead of `fromString` (#2, sjakobi).
    This produces a further reduction in allocations and
    pandoc compile time.
* Sun Mar 14 2021 psimons@suse.com
- Update doclayout to version 0.3.0.1.
  [#]# 0.3.0.1
  * NOINLINE `fromString` (#1).
    @sjakobi reports that this change reduced total allocations
    for building pandoc-2.12 with GHC 8.10.4 by 8.5%% and reduced
    peak allocations are reduced from 3854MB to 3389MB.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Thu Feb 27 2020 psimons@suse.com
- Update doclayout to version 0.3.
  [#]# 0.3
  * Add foldlChar to signature of HasChars [API change].
  * Use foldlChar in realLength. This avoids a stack overflow
    we were getting with long strings in the previous version
    (with foldrChar).  See jgm/pandoc#6031.
  * Replace isBlank with isBreakable and improved startsWithBlank.
    Previously isBlank was used in the layout algorithm where
    what we really wanted was isBreakable.
  * Avoid unnecessary calculation in updateColumns.
  * Replace a right fold with a strict left fold.
  * Add strictness annotations in realLength and updateColumn.
* Sat Dec 21 2019 psimons@suse.com
- Add doclayout at version 0.2.0.1.
